@@ -258,6 +258,13 @@ std::string launchQuickStart(int &_argc, char **_argv,
 
   gzdbg << "Reading Quick start menu config." << std::endl;
   auto showDialog = dialog->ReadConfigAttribute(_configInUse, "show_again");
+  // Quick start menu is not supported on Windows at the moment, see
+  // https://github.com/gazebosim/gz-sim/issues/3106
+  #ifdef _WIN32
+  gzdbg << "Hardcoding Quick start menu config to "
+        << "false as we are on Windows." << std::endl;
+  showDialog = "false";
+  #endif
   if (showDialog == "false")
   {
     gzmsg << "Not showing Quick start menu." << std::endl;
@@ -332,6 +339,20 @@ std::unique_ptr<gz::gui::Application> createGui(
   gzmsg << "Gazebo Sim GUI    v" << GZ_SIM_VERSION_FULL
          << std::endl;
 
+  gzdbg << "Qt Prefix:"
+        << QLibraryInfo::path(QLibraryInfo::PrefixPath).toStdString() << "\n";
+  gzdbg << "Qt libs:"
+        << QLibraryInfo::path(QLibraryInfo::LibrariesPath).toStdString()
+        << "\n";
+  gzdbg << "Qt data:"
+        << QLibraryInfo::path(QLibraryInfo::DataPath).toStdString() << " arch:"
+        << QLibraryInfo::path(QLibraryInfo::ArchDataPath).toStdString() << "\n";
+  gzdbg << "Qt plugins:"
+        << QLibraryInfo::path(QLibraryInfo::PluginsPath).toStdString() << "\n";
+  gzdbg << "Qt imports:"
+        << QLibraryInfo::path(QLibraryInfo::QmlImportsPath).toStdString()
+        << "\n";
+
   // Set auto scaling factor for HiDPI displays
   if (QString::fromLocal8Bit(qgetenv("QT_AUTO_SCREEN_SCALE_FACTOR")).isEmpty())
   {
@@ -434,8 +455,8 @@ std::unique_ptr<gz::gui::Application> createGui(
 
   // Let QML files use C++ functions and properties
   auto context = new QQmlContext(app->Engine()->rootContext());
-  context->setContextProperty("AboutDialogHandler", aboutDialogHandler);
-  context->setContextProperty("GuiFileHandler", guiFileHandler);
+  context->setContextProperty("_AboutDialogHandler", aboutDialogHandler);
+  context->setContextProperty("_GuiFileHandler", guiFileHandler);
 
   // Instantiate GazeboDrawer.qml file into a component
   QQmlComponent component(app->Engine(), ":/Gazebo/GazeboDrawer.qml");
@@ -452,6 +473,10 @@ std::unique_ptr<gz::gui::Application> createGui(
   }
   else
   {
+    if (component.isError())
+    {
+      qWarning() << component.errors();
+    }
     gzerr << "Failed to instantiate custom drawer, drawer will be empty"
            << std::endl;
   }
