@@ -212,11 +212,23 @@ ApplyForceTorque::ApplyForceTorque()
 /////////////////////////////////////////////////
 ApplyForceTorque::~ApplyForceTorque()
 {
+  // Remove event filter to prevent events from being sent to a destroyed object
+  auto mainWindow = gz::gui::App()->findChild<gz::gui::MainWindow *>();
+  if (mainWindow)
+    mainWindow->removeEventFilter(this);
+
   if (!this->dataPtr->scene)
     return;
+  // Destroy rendering nodes to release resources
   this->dataPtr->scene->DestroyNode(this->dataPtr->forceVisual, true);
   this->dataPtr->scene->DestroyNode(this->dataPtr->torqueVisual, true);
   this->dataPtr->scene->DestroyNode(this->dataPtr->gizmoVisual, true);
+
+  // Set pointers to nullptr to avoid dangling references
+  this->dataPtr->forceVisual = nullptr;
+  this->dataPtr->torqueVisual = nullptr;
+  this->dataPtr->gizmoVisual = nullptr;
+  this->dataPtr->scene = nullptr;
 }
 
 /////////////////////////////////////////////////
@@ -232,7 +244,7 @@ void ApplyForceTorque::LoadConfig(const tinyxml2::XMLElement */*_pluginElem*/)
     this->dataPtr->worldName = worldNames[0].toStdString();
     auto topic = transport::TopicUtils::AsValidTopic(
       "/world/" + this->dataPtr->worldName + "/wrench");
-    if (topic == "")
+    if (topic.empty())
     {
       gzerr << "Unable to create publisher" << std::endl;
       return;
@@ -764,7 +776,7 @@ void ApplyForceTorquePrivate::UpdateVisuals()
     // https://github.com/gazebosim/gz-rendering/pull/882
 
     // Update gizmo visual rotation so that they are always facing the
-    // eye position and alligned with the active vector
+    // eye position and aligned with the active vector
     math::Quaterniond gizmoRot = this->linkWorldPose.Rot() * this->vectorRot;
     math::Vector3d eye = gizmoRot.RotateVectorReverse(
       (this->camera->WorldPosition() - pos).Normalized());
