@@ -359,7 +359,7 @@ class VisualCommand : public UserCommandBase
   // Documentation inherited
   public: bool Execute() final;
 
-  /// \brief Visual equality comparision function
+  /// \brief Visual equality comparison function
   /// TODO(anyone) Currently only checks for material colors equality,
   /// need to extend to others
   public: std::function<bool(const msgs::Visual &, const msgs::Visual &)>
@@ -416,7 +416,7 @@ class WheelSlipCommand : public UserCommandBase
   // Documentation inherited
   public: bool Execute() final;
 
-  /// \brief WheelSlip equality comparision function
+  /// \brief WheelSlip equality comparison function
   public: std::function<bool(
     const msgs::WheelSlipParametersCmd &, const msgs::WheelSlipParametersCmd &)>
           wheelSlipEql {
@@ -573,6 +573,13 @@ bool UserCommandsInterface::HasContactSensor(const Entity _collision)
   return false;
 }
 
+//////////////////////////////////////////////////
+System::PriorityType UserCommands::ConfigurePriority()
+{
+  // Use constant from System.hh
+  return ::gz::sim::systems::kUserCommandsPriority;
+}
+
 //////////////////////////////////////////////////
 void UserCommands::Configure(const Entity &_entity,
     const std::shared_ptr<const sdf::Element> &_sdf,
@@ -1051,7 +1058,6 @@ bool CreateCommand::CreateFromMsg(const msgs::EntityFactory &_createMsg)
   // Spherical coordinates
   if (_createMsg.has_spherical_coordinates())
   {
-    gzerr << "HasSphericalCoordinates" << std::endl;
     auto scComp = this->iface->ecm->Component<components::SphericalCoordinates>(
         this->iface->worldEntity);
     if (nullptr == scComp)
@@ -1063,25 +1069,33 @@ bool CreateCommand::CreateFromMsg(const msgs::EntityFactory &_createMsg)
     }
     else
     {
-      // deg to rad
-      math::Vector3d latLonEle{
+      auto vec = math::CoordinateVector3::Spherical(
           GZ_DTOR(_createMsg.spherical_coordinates().latitude_deg()),
           GZ_DTOR(_createMsg.spherical_coordinates().longitude_deg()),
-          _createMsg.spherical_coordinates().elevation()};
-
-      auto pos = scComp->Data().PositionTransform(latLonEle,
+          _createMsg.spherical_coordinates().elevation());
+      auto pos = scComp->Data().PositionTransform(vec,
           math::SphericalCoordinates::SPHERICAL,
-          math::SphericalCoordinates::LOCAL2);
+          math::SphericalCoordinates::LOCAL);
 
-      // Override pos and add to yaw
-      if (!createPose.has_value())
-        createPose = math::Pose3d::Zero;
-      createPose.value().SetX(pos.X());
-      createPose.value().SetY(pos.Y());
-      createPose.value().SetZ(pos.Z());
-      createPose.value().Rot() = math::Quaterniond(0, 0,
-          GZ_DTOR(_createMsg.spherical_coordinates().heading_deg())) *
-          createPose.value().Rot();
+      if (!pos.has_value() || !pos->IsMetric())
+      {
+        gzerr << "Trying to create entity [" << desiredName
+              << "] using spherical coordinates, but spherical to local "
+              << "position conversion failed. Entity will be created at the "
+              << "world origin." << std::endl;
+      }
+      else
+      {
+        // Override pos and add to yaw
+        if (!createPose.has_value())
+          createPose = math::Pose3d::Zero;
+        createPose.value().SetX(*pos->X());
+        createPose.value().SetY(*pos->Y());
+        createPose.value().SetZ(*pos->Z());
+        createPose.value().Rot() = math::Quaterniond(0, 0,
+            GZ_DTOR(_createMsg.spherical_coordinates().heading_deg())) *
+            createPose.value().Rot();
+      }
     }
   }
 
@@ -1471,17 +1485,22 @@ bool SphericalCoordinatesCommand::Execute()
     return false;
   }
 
-  // deg to rad
-  math::Vector3d latLonEle{
+  auto vec = math::CoordinateVector3::Spherical(
       GZ_DTOR(sphericalCoordinatesMsg->latitude_deg()),
       GZ_DTOR(sphericalCoordinatesMsg->longitude_deg()),
-      sphericalCoordinatesMsg->elevation()};
-
-  auto pos = scComp->Data().PositionTransform(latLonEle,
+      sphericalCoordinatesMsg->elevation());
+  auto pos = scComp->Data().PositionTransform(vec,
       math::SphericalCoordinates::SPHERICAL,
-      math::SphericalCoordinates::LOCAL2);
+      math::SphericalCoordinates::LOCAL);
+  if (!pos.has_value() || !pos->IsMetric())
+  {
+    gzerr << "Trying to move entity [" << entity
+           << "] using spherical coordinates, but spherical to local "
+           << "position conversion failed." << std::endl;
+    return false;
+  }
 
-  math::Pose3d pose{pos.X(), pos.Y(), pos.Z(), 0, 0,
+  math::Pose3d pose{*pos->X(), *pos->Y(), *pos->Z(), 0, 0,
           GZ_DTOR(sphericalCoordinatesMsg->heading_deg())};
 
   auto poseCmdComp =
